Jira Assistant - Connect Excel with Jira
=============================================

|ProjectLogo|

.. |ProjectLogo| image:: https://raw.githubusercontent.com/jira-assistant/jira-assistant/main/docs/img/logo.png
    :target: https://github.com/jira-assistant/jira-assistant
    :alt: Jira Assistant

|PyPI| |SupportedVersions| |dependencyStatus| |Download| |GitHubCommit| |Package Size| |CodeFactor| |GithubIssues| |Linux| |Windows| |Mac OS| |MyPy| |Pylint| |CodeQL| |Documentation| |Codecov| |License|

.. |PyPI| image:: https://img.shields.io/pypi/v/jira-assistant.svg?style=flat-square
    :target: https://pypi.org/project/jira-assistant/
    :alt: PyPI version

.. |SupportedVersions| image:: https://img.shields.io/pypi/pyversions/jira-assistant
    :target: https://pypi.org/project/jira-assistant/
    :alt: Supported versions

.. |dependencyStatus| image:: https://img.shields.io/librariesio/release/pypi/jira-assistant
   :target: https://pypi.org/project/jira-assistant/
   :alt: Libraries.io dependency status for latest release

.. |Download| image:: https://img.shields.io/pepy/dt/jira-assistant
   :target: https://pepy.tech/projects/jira-assistant
   :alt: Pepy Total Downloads

.. |GitHubCommit| image:: https://img.shields.io/github/commit-activity/m/jira-assistant/jira-assistant
    :target: https://github.com/jira-assistant/jira-assistant
    :alt: GitHub commit activity

.. |Package Size| image:: https://img.shields.io/github/repo-size/jira-assistant/jira-assistant
    :target: https://img.shields.io/github/repo-size/jira-assistant/jira-assistant
    :alt: Package Size

.. |GitHubIssues| image:: https://img.shields.io/github/issues/jira-assistant/jira-assistant
   :target: https://github.com/jira-assistant/jira-assistant/issues
   :alt: GitHub issues

.. |Linux| image:: https://github.com/jira-assistant/jira-assistant/actions/workflows/python-3-linux-test.yml/badge.svg
    :target: https://github.com/jira-assistant/jira-assistant/actions/workflows/python-3-linux-test.yml
    :alt: python 3.11 (Linux)

.. |Mac OS| image:: https://github.com/jira-assistant/jira-assistant/actions/workflows/python-3-macos-test.yml/badge.svg
    :target: https://github.com/jira-assistant/jira-assistant/actions/workflows/python-3-macos-test.yml
    :alt: python 3.11 (Mac OS)

.. |Windows| image:: https://github.com/jira-assistant/jira-assistant/actions/workflows/python-3-windows-test.yml/badge.svg
    :target: https://github.com/jira-assistant/jira-assistant/actions/workflows/python-3-windows-test.yml
    :alt: python 3.11 (Windows)

.. |Pylint| image:: https://github.com/jira-assistant/jira-assistant/actions/workflows/pylint.yml/badge.svg
    :target: https://github.com/jira-assistant/jira-assistant/actions/workflows/pylint.yml
    :alt: Pylint 

.. |MyPy| image:: https://github.com/jira-assistant/jira-assistant/actions/workflows/mypy.yml/badge.svg
    :target: https://github.com/jira-assistant/jira-assistant/actions/workflows/mypy.yml
    :alt: MyPy 

.. |CodeQL| image:: https://github.com/jira-assistant/jira-assistant/workflows/CodeQL/badge.svg
    :target: https://github.com/jira-assistant/jira-assistant/actions/workflows/CodeQL.yml
    :alt: CodeQL 

.. |Documentation| image:: https://readthedocs.org/projects/jira-assistant/badge/?version=latest
    :target: https://jira-assistant.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |Codecov| image:: https://codecov.io/gh/jira-assistant/jira-assistant/branch/main/graph/badge.svg?token=CRNM1vEsGf
    :target: https://codecov.io/gh/jira-assistant/jira-assistant
    :alt: Codecov

.. |CodeFactor| image:: https://www.codefactor.io/repository/github/jira-assistant/jira-assistant/badge
   :target: https://www.codefactor.io/repository/github/jira-assistant/jira-assistant
   :alt: CodeFactor

.. |License| image:: https://img.shields.io/github/license/jira-assistant/jira-assistant
   :target: https://img.shields.io/github/license/jira-assistant/jira-assistant
   :alt: License

Collecting Ideas!!!
===================
If you have any ideas or good requirements related to this package, please let us know and we will do our best to fulfill! Please send emails to <sharry.xu@outlook.com>.

Documentation
=============
For full documentation, including installation, tutorials and PDF documents, please see https://jira-assistant.readthedocs.io/en/stable/

Installation
============
`jira-assistant` can be installed from PyPI using `pip` ::

    pip install -U jira-assistant

Download
========
jira-assistant is available on PyPI
https://pypi.org/project/jira-assistant

Code
====
The code and issue tracker are hosted on GitHub:
https://github.com/jira-assistant/jira-assistant

Features
========

* Currently using the Jira platform to gather the necessary information to complete the Excel file.
* Able to create new stories on the Jira platform as needed.
* There are multiple defined procedures available to retrieve additional information, apply customized filters and more, which can be combined to process the Excel file.
* The Excel rows can be sorted using multiple sorting algorithms that can also be combined as per your requirement.

Author
======
The jira-assistant was written by Sharry Xu <sharry.xu@outlook.com> in 2022.

Starting with version 0.1.5, the main function of this project has been totally finished.

License
=======
All contributions after December 1, 2022 released under MIT license.
